@@ -488,6 +488,9 @@ impl QMetaType for QVariant {
     }
 }
 qdeclare_builtin_metatype! {QModelIndex => 42}
+qdeclare_builtin_metatype! {QJsonValue => 45}
+qdeclare_builtin_metatype! {QJsonObject => 46}
+qdeclare_builtin_metatype! {QJsonArray => 47}
 qdeclare_builtin_metatype! {QPixmap => if cfg!(qt_6_0) { 0x1001 } else { 65 }}
 qdeclare_builtin_metatype! {QColor => if cfg!(qt_6_0) { 0x1003 } else { 67 }}
 qdeclare_builtin_metatype! {QImage => if cfg!(qt_6_0) { 0x1006 } else { 70 }}
